Class: Google::Api::BatchingDescriptorProto

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/api/client.rb

Overview

BatchingDescriptorProto specifies the fields of the request message to be used for batching, and, optionally, the fields of the response message to be used for demultiplexing.

Instance Attribute Summary collapse

Instance Attribute Details

#batched_field ⇒ ::String



531
532
533
534
# File 'proto_docs/google/api/client.rb', line 531

class BatchingDescriptorProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#discriminator_fields ⇒ ::Array<::String>



531
532
533
534
# File 'proto_docs/google/api/client.rb', line 531

class BatchingDescriptorProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#subresponse_field ⇒ ::String



531
532
533
534
# File 'proto_docs/google/api/client.rb', line 531

class BatchingDescriptorProto
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end