Class: Google::Shopping::Merchant::LoyaltyCustomers::V1::ManageLoyaltyCustomerMatchRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb

Overview

Request message for the ManageLoyaltyCustomerMatch method.

Instance Attribute Summary collapse

Instance Attribute Details

#loyalty_customer ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomer

Returns Required. The loyalty customer to insert, update, or remove.

Returns:



131
132
133
134
# File 'proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb', line 131

class ManageLoyaltyCustomerMatchRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent ⇒ ::String

Returns Required. The parent account where this loyalty customer will be handled. Format: accounts/{account}.

Returns:

  • (::String) —

    Required. The parent account where this loyalty customer will be handled. Format: accounts/{account}



131
132
133
134
# File 'proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb', line 131

class ManageLoyaltyCustomerMatchRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end