Class: Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomer
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomer
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb
Overview
Represents a customer’s loyalty information.
Represents loyalty customer data in ManageLoyaltyCustomerMatch API, but
is not a resource that can be retrieved or listed by other methods.
Defined Under Namespace
Modules: LoyaltyTier
Instance Attribute Summary collapse
-
#loyalty_tier ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomer::LoyaltyTier
Required.
-
#point_balance ⇒ ::Integer
Optional.
-
#user_identifier ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::UserIdentifier
Required.
Instance Attribute Details
#loyalty_tier ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomer::LoyaltyTier
Returns Required. The tier label of the loyalty tier the customer belongs to.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb', line 86 class LoyaltyCustomer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The tier label of the loyalty tier the customer belongs to. module LoyaltyTier # Loyalty tier unspecified. LOYALTY_TIER_UNSPECIFIED = 0 # Loyalty tier 1. TIER1 = 1 # Loyalty tier 2. TIER2 = 2 # Loyalty tier 3. TIER3 = 3 # Loyalty tier 4. TIER4 = 4 # Loyalty tier 5. TIER5 = 5 # Loyalty tier 6. TIER6 = 6 # Loyalty tier 7. TIER7 = 7 # Disassociates the user from any loyalty tier. Only set to “NON_MEMBER” # when the intent is to remove the user association from Google organic # loyalty customer match experience. NON_MEMBER = 8 end end |
#point_balance ⇒ ::Integer
Returns Optional. The point balance of the loyalty customer.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb', line 86 class LoyaltyCustomer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The tier label of the loyalty tier the customer belongs to. module LoyaltyTier # Loyalty tier unspecified. LOYALTY_TIER_UNSPECIFIED = 0 # Loyalty tier 1. TIER1 = 1 # Loyalty tier 2. TIER2 = 2 # Loyalty tier 3. TIER3 = 3 # Loyalty tier 4. TIER4 = 4 # Loyalty tier 5. TIER5 = 5 # Loyalty tier 6. TIER6 = 6 # Loyalty tier 7. TIER7 = 7 # Disassociates the user from any loyalty tier. Only set to “NON_MEMBER” # when the intent is to remove the user association from Google organic # loyalty customer match experience. NON_MEMBER = 8 end end |
#user_identifier ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::UserIdentifier
Returns Required. The identifiers for the customer.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb', line 86 class LoyaltyCustomer include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The tier label of the loyalty tier the customer belongs to. module LoyaltyTier # Loyalty tier unspecified. LOYALTY_TIER_UNSPECIFIED = 0 # Loyalty tier 1. TIER1 = 1 # Loyalty tier 2. TIER2 = 2 # Loyalty tier 3. TIER3 = 3 # Loyalty tier 4. TIER4 = 4 # Loyalty tier 5. TIER5 = 5 # Loyalty tier 6. TIER6 = 6 # Loyalty tier 7. TIER7 = 7 # Disassociates the user from any loyalty tier. Only set to “NON_MEMBER” # when the intent is to remove the user association from Google organic # loyalty customer match experience. NON_MEMBER = 8 end end |