Module: Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomerMatchService
- Defined in:
- lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service.rb,
lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/rest.rb,
lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/paths.rb,
lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/client.rb,
lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/credentials.rb,
lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/rest/client.rb,
lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/rest/service_stub.rb
Overview
Manages customer loyalty program memberships for merchants.
This service allows all merchants, including non-advertisers, to share their first-party customer data of loyalty program members. Google uses this data to personalize organic free listing shopping experiences, in compliance with the Merchant Center Terms of Service.
The service follows a non-standard, imperative pattern,
exposing a single ManageLoyaltyCustomerMatch method rather than
conventional resource identifiers and CRUD operations. This design protects
user privacy by preventing the discovery of a customer's presence or
membership status through standard GET or LIST methods.
To load this service and instantiate a REST client:
require "google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/rest"
client = ::Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomerMatchService::Rest::Client.new
Defined Under Namespace
Modules: Paths, Rest Classes: Client, Credentials