Class: Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomerMatchService::Client
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomerMatchService::Client
- Includes:
- Paths
- Defined in:
- lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/client.rb
Overview
Client for the LoyaltyCustomerMatchService service.
Manages customer loyalty program memberships for merchants.
This service allows all merchants, including non-advertisers, to share their first-party customer data of loyalty program members. Google uses this data to personalize organic free listing shopping experiences, in compliance with the Merchant Center Terms of Service.
The service follows a non-standard, imperative pattern,
exposing a single ManageLoyaltyCustomerMatch method rather than
conventional resource identifiers and CRUD operations. This design protects
user privacy by preventing the discovery of a customer's presence or
membership status through standard GET or LIST methods.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the LoyaltyCustomerMatchService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the LoyaltyCustomerMatchService Client instance.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new LoyaltyCustomerMatchService client object.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#manage_loyalty_customer_match(request, options = nil) {|response, operation| ... } ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::ManageLoyaltyCustomerMatchResponse
Manages (inserts, updates, or removes) a customer's loyalty tier information.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new LoyaltyCustomerMatchService client object.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/client.rb', line 143 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/shopping/merchant/loyaltycustomers/v1/loyalty_customer_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @loyalty_customer_match_service_stub = ::Gapic::ServiceStub.new( ::Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomerMatchService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @loyalty_customer_match_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the LoyaltyCustomerMatchService Client class.
See Configuration for a description of the configuration fields.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/client.rb', line 76 def self.configure @configure ||= begin namespace = ["Google", "Shopping", "Merchant", "LoyaltyCustomers", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.timeout = 60.0 default_config.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the LoyaltyCustomerMatchService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
113 114 115 116 |
# File 'lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/client.rb', line 113 def configure yield @config if block_given? @config end |
#logger ⇒ Logger
The logger used for request/response debug logging.
199 200 201 |
# File 'lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/client.rb', line 199 def logger @loyalty_customer_match_service_stub.logger end |
#manage_loyalty_customer_match(request, options = nil) ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::ManageLoyaltyCustomerMatchResponse #manage_loyalty_customer_match(parent: nil, loyalty_customer: nil) ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::ManageLoyaltyCustomerMatchResponse
Manages (inserts, updates, or removes) a customer's loyalty tier information.
This method serves as a single interface for all changes to a customer's
loyalty status. The specific action (insert, update, or remove) is
determined by the current state of the merchant-to-customer association and
the loyalty_tier value provided in the request.
Operation Logic:
- Upsert (Insert/Update): Providing any valid tier other than
NON_MEMBERwill associate the customer with that tier. If an association already exists, it will be updated; otherwise, a new one will be created. - Removal: Setting
loyalty_tiertoNON_MEMBERwill remove any existing loyalty association for the customer.
Privacy Note: To protect user privacy, this method consistently returns
a 200 OK status with a default LoyaltyCustomer response if the
customer's identifier cannot be matched to a Google account or if the user
has not opted into loyalty personalization.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/client.rb', line 271 def manage_loyalty_customer_match request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Shopping::Merchant::LoyaltyCustomers::V1::ManageLoyaltyCustomerMatchRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.manage_loyalty_customer_match..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Shopping::Merchant::LoyaltyCustomers::V1::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.manage_loyalty_customer_match.timeout, metadata: , retry_policy: @config.rpcs.manage_loyalty_customer_match.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @loyalty_customer_match_service_stub.call_rpc :manage_loyalty_customer_match, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
123 124 125 |
# File 'lib/google/shopping/merchant/loyalty_customers/v1/loyalty_customer_match_service/client.rb', line 123 def universe_domain @loyalty_customer_match_service_stub.universe_domain end |