Class: Google::Shopping::Merchant::LoyaltyCustomers::V1::ManageLoyaltyCustomerMatchResponse
- Inherits:
-
Object
- Object
- Google::Shopping::Merchant::LoyaltyCustomers::V1::ManageLoyaltyCustomerMatchResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb
Overview
Response message for the ManageLoyaltyCustomerMatch method.
Instance Attribute Summary collapse
-
#loyalty_customer ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomer
The loyalty customer that was inserted, updated, or removed.
Instance Attribute Details
#loyalty_customer ⇒ ::Google::Shopping::Merchant::LoyaltyCustomers::V1::LoyaltyCustomer
Returns The loyalty customer that was inserted, updated, or removed.
If the customer's identifier cannot be matched to a Google account or if
the user has not opted into loyalty personalization, this field will
contain a default LoyaltyCustomer instance.
143 144 145 146 |
# File 'proto_docs/google/shopping/merchant/loyaltycustomers/v1/loyalty_customer.rb', line 143 class ManageLoyaltyCustomerMatchResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |